@@ -79,6 +79,16 @@ static XErrorHandler defaultHandler;
 
 #endif
 
+#define POLLER_CALL(Object, Method) \
+    if (Object != 0) { \
+        AbstractSystemPoller *t = qobject_cast<AbstractSystemPoller *>(Object); \
+        if (t!=0) { \
+            t->Method; \
+        } \
+    } else { \
+        kWarning() << "WARNING: No poller system loaded, PowerDevil can not detect idle time"; \
+    }
+
 K_PLUGIN_FACTORY(PowerDevilFactory,
                  registerPlugin<PowerDevilDaemon>();)
 K_EXPORT_PLUGIN(PowerDevilFactory("powerdevildaemon"))
@@ -123,21 +133,7 @@ PowerDevilDaemon::PowerDevilDaemon(QObject *parent, const QList<QVariant>&)
     m_profilesConfig = KSharedConfig::openConfig("powerdevilprofilesrc", KConfig::SimpleConfig);
     setAvailableProfiles(m_profilesConfig->groupList());
 
-    /* You'll see some switches on m_battery. This is fundamental since PowerDevil might run
-     * also on system without batteries. Most of modern desktop systems support CPU scaling,
-     * so somebody might find PowerDevil handy, and we don't want it to crash on them. To put it
-     * short, we simply bypass all adaptor and battery events if no batteries are found.
-     */
-
-    // Here we get our battery interface, it will be useful later.
-    foreach(const Solid::Device &device, Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString())) {
-        Solid::Device d = device;
-        Solid::Battery *b = qobject_cast<Solid::Battery*> (d.asDeviceInterface(Solid::DeviceInterface::Battery));
-        if (b->type() != Solid::Battery::PrimaryBattery) {
-            continue;
-        }
-        m_battery = b;
-    }
+    recacheBatteryPointer(true);
 
     // Set up all needed DBus interfaces
     m_screenSaverIface = new OrgFreedesktopScreenSaverInterface("org.freedesktop.ScreenSaver", "/ScreenSaver",
@@ -153,19 +149,6 @@ PowerDevilDaemon::PowerDevilDaemon(QObject *parent, const QList<QVariant>&)
             SLOT(emitCriticalNotification(const QString&, const QString&,
                                           const char*, const QString&)));
 
-    /* Those slots are relevant only if we're on a system that has a battery. If not, we simply don't care
-     * about them.
-     */
-    if (m_battery) {
-        connect(m_notifier, SIGNAL(acAdapterStateChanged(int)), this, SLOT(acAdapterStateChanged(int)));
-
-        if (!connect(m_battery, SIGNAL(chargePercentChanged(int, const QString &)), this,
-                     SLOT(batteryChargePercentChanged(int, const QString &)))) {
-            emitCriticalNotification("powerdevilerror", i18n("Could not connect to battery interface!\n"
-                                     "Please check your system configuration"));
-        }
-    }
-
     /* Time for setting up polling! We can have different methods, so
      * let's check what we got.
      */
@@ -203,6 +186,56 @@ PowerDevilDaemon::~PowerDevilDaemon()
     delete m_currentConfig;
 }
 
+bool PowerDevilDaemon::recacheBatteryPointer(bool force)
+{
+    /* You'll see some switches on m_battery. This is fundamental since PowerDevil might run
+     * also on system without batteries. Most of modern desktop systems support CPU scaling,
+     * so somebody might find PowerDevil handy, and we don't want it to crash on them. To put it
+     * short, we simply bypass all adaptor and battery events if no batteries are found.
+     */
+
+    if (m_battery) {
+        if (m_battery->isValid() && !force) {
+            return true;
+        }
+    }
+
+    m_battery = 0;
+
+    // Here we get our battery interface, it will be useful later.
+    foreach(const Solid::Device &device, Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString())) {
+        Solid::Device d = device;
+        Solid::Battery *b = qobject_cast<Solid::Battery*> (d.asDeviceInterface(Solid::DeviceInterface::Battery));
+
+        if (b->type() != Solid::Battery::PrimaryBattery) {
+            continue;
+        }
+
+        if (b->isValid()) {
+            m_battery = b;
+        }
+    }
+
+    /* Those slots are relevant only if we're on a system that has a battery. If not, we simply don't care
+     * about them.
+     */
+    if (m_battery) {
+        connect(m_notifier, SIGNAL(acAdapterStateChanged(int)), this, SLOT(acAdapterStateChanged(int)));
+
+        if (!connect(m_battery, SIGNAL(chargePercentChanged(int, const QString &)), this,
+                     SLOT(batteryChargePercentChanged(int, const QString &)))) {
+
+            emitCriticalNotification("powerdevilerror", i18n("Could not connect to battery interface!\n"
+                                     "Please check your system configuration"));
+            return false;
+        }
+    } else {
+        return false;
+    }
+
+    return true;
+}
+
 void PowerDevilDaemon::setUpPollingSystem()
 {
     if (!loadPollingSystem((AbstractSystemPoller::PollingType) PowerDevilSettings::pollingSystem())) {
@@ -277,8 +310,8 @@ void PowerDevilDaemon::resumeFromIdle()
 
     Solid::Control::PowerManager::setBrightness(settings->readEntry("brightness").toInt());
 
-    m_pollLoader->poller()->stopCatchingIdleEvents();
-    m_pollLoader->poller()->forcePollRequest();
+    POLLER_CALL(m_pollLoader->poller(), stopCatchingIdleEvents());
+    POLLER_CALL(m_pollLoader->poller(), forcePollRequest());
 }
 
 void PowerDevilDaemon::refreshStatus()
@@ -365,7 +398,7 @@ void PowerDevilDaemon::applyProfile()
 
     Solid::Control::PowerManager::setScheme(settings->readEntry("scheme"));
 
-    m_pollLoader->poller()->forcePollRequest();
+    POLLER_CALL(m_pollLoader->poller(), forcePollRequest());
 }
 
 void PowerDevilDaemon::setUpDPMS()
@@ -699,7 +732,7 @@ void PowerDevilDaemon::suspendToDisk(bool automated)
         return;
     }
 
-    m_pollLoader->poller()->simulateUserActivity(); //prevent infinite suspension loops
+    POLLER_CALL(m_pollLoader->poller(), simulateUserActivity()); //prevent infinite suspension loops
 
     if (PowerDevilSettings::configLockScreen()) {
         lockScreen();
@@ -719,7 +752,7 @@ void PowerDevilDaemon::suspendToRam(bool automated)
         return;
     }
 
-    m_pollLoader->poller()->simulateUserActivity(); //prevent infinite suspension loops
+    POLLER_CALL(m_pollLoader->poller(), simulateUserActivity()); //prevent infinite suspension loops
 
     if (PowerDevilSettings::configLockScreen()) {
         lockScreen();
@@ -738,7 +771,7 @@ void PowerDevilDaemon::standby(bool automated)
         return;
     }
 
-    m_pollLoader->poller()->simulateUserActivity(); //prevent infinite suspension loops
+    POLLER_CALL(m_pollLoader->poller(), simulateUserActivity()); //prevent infinite suspension loops
 
     if (PowerDevilSettings::configLockScreen()) {
         lockScreen();
@@ -759,7 +792,7 @@ void PowerDevilDaemon::suspendJobResult(KJob * job)
                                  + QChar('\n') + job->errorString()));
     }
 
-    m_pollLoader->poller()->simulateUserActivity(); //prevent infinite suspension loops
+    POLLER_CALL(m_pollLoader->poller(), simulateUserActivity()); //prevent infinite suspension loops
 
     kDebug() << "Resuming from suspension";
 
@@ -787,7 +820,7 @@ void PowerDevilDaemon::poll(int idle)
     if (!settings->readEntry("dimOnIdle", false) && !settings->readEntry("turnOffIdle", false) &&
             settings->readEntry("idleAction").toInt() == None) {
         kDebug() << "Stopping timer";
-        m_pollLoader->poller()->stopCatchingTimeouts();
+        POLLER_CALL(m_pollLoader->poller(), stopCatchingTimeouts());
         return;
     }
 
@@ -815,7 +848,7 @@ void PowerDevilDaemon::poll(int idle)
 
     if (idle < minTime) {
         int remaining = minTime - idle;
-        m_pollLoader->poller()->setNextTimeout(remaining * 1000);
+        POLLER_CALL(m_pollLoader->poller(), setNextTimeout(remaining * 1000));
         kDebug() << "Nothing to do, next event in" << remaining << "seconds";
         return;
     }
@@ -833,23 +866,23 @@ void PowerDevilDaemon::poll(int idle)
 
         switch (settings->readEntry("idleAction").toInt()) {
         case Shutdown:
-            m_pollLoader->poller()->catchIdleEvent();
+            POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
             shutdownNotification(true);
             break;
         case S2Disk:
-            m_pollLoader->poller()->catchIdleEvent();
+            POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
             suspendToDiskNotification(true);
             break;
         case S2Ram:
-            m_pollLoader->poller()->catchIdleEvent();
+            POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
             suspendToRamNotification(true);
             break;
         case Standby:
-            m_pollLoader->poller()->catchIdleEvent();
+            POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
             standbyNotification(true);
             break;
         case Lock:
-            m_pollLoader->poller()->catchIdleEvent();
+            POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
             lockScreen();
             break;
         default:
@@ -860,20 +893,20 @@ void PowerDevilDaemon::poll(int idle)
 
     } else if (settings->readEntry("dimOnIdle", false)
                && (idle >= dimOnIdleTime)) {
-        m_pollLoader->poller()->catchIdleEvent();
+        POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
         Solid::Control::PowerManager::setBrightness(0);
     } else if (settings->readEntry("dimOnIdle", false)
                && (idle >= (dimOnIdleTime * 3 / 4))) {
-        m_pollLoader->poller()->catchIdleEvent();
+        POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
         float newBrightness = Solid::Control::PowerManager::brightness() / 4;
         Solid::Control::PowerManager::setBrightness(newBrightness);
     } else if (settings->readEntry("dimOnIdle", false) &&
                (idle >= (dimOnIdleTime * 1 / 2))) {
-        m_pollLoader->poller()->catchIdleEvent();
+        POLLER_CALL(m_pollLoader->poller(), catchIdleEvent());
         float newBrightness = Solid::Control::PowerManager::brightness() / 2;
         Solid::Control::PowerManager::setBrightness(newBrightness);
     } else {
-        m_pollLoader->poller()->stopCatchingIdleEvents();
+        POLLER_CALL(m_pollLoader->poller(), stopCatchingIdleEvents());
         Solid::Control::PowerManager::setBrightness(settings->readEntry("brightness").toInt());
     }
 
@@ -902,10 +935,10 @@ void PowerDevilDaemon::setUpNextTimeout(int idle, int minDimEvent)
     }
 
     if (nextTimeout >= 0) {
-        m_pollLoader->poller()->setNextTimeout(nextTimeout * 1000);
+        POLLER_CALL(m_pollLoader->poller(), setNextTimeout(nextTimeout * 1000));
         kDebug() << "Next timeout in" << nextTimeout << "seconds";
     } else {
-        m_pollLoader->poller()->stopCatchingTimeouts();
+        POLLER_CALL(m_pollLoader->poller(), stopCatchingTimeouts());
         kDebug() << "Stopping timer";
     }
 }
@@ -1039,7 +1072,7 @@ KConfigGroup * PowerDevilDaemon::getCurrentProfile(bool forcereload)
 
 void PowerDevilDaemon::reloadProfile(int state)
 {
-    if (!m_battery) {
+    if (!recacheBatteryPointer()) {
         setCurrentProfile(PowerDevilSettings::aCProfile());
     } else {
         if (state == -1) {
@@ -1084,7 +1117,7 @@ void PowerDevilDaemon::reloadProfile(int state)
         }
     }
 
-    m_pollLoader->poller()->forcePollRequest();
+    POLLER_CALL(m_pollLoader->poller(), forcePollRequest());
 }
 
 void PowerDevilDaemon::setProfile(const QString & profile)
@@ -1095,11 +1128,7 @@ void PowerDevilDaemon::setProfile(const QString & profile)
      * to be loaded!!
      */
 
-    if (m_battery) {
-        acAdapterStateChanged(Solid::Control::PowerManager::acAdapterState(), true);
-    } else {
-        applyProfile();
-    }
+    applyProfile();
 
     KConfigGroup * settings = getCurrentProfile();
 
