@@ -22,7 +22,7 @@
 
 #include "AbstractSystemPoller.h"
 
-#include <config-X11.h>
+#include <config-powerdevil.h>
 
 #include <KApplication>
 #include <KDebug>
@@ -84,6 +84,7 @@ private:
     XSyncAlarm          m_resetAlarm;
 #endif
     QWidget * m_filterWidget;
+    bool m_error;
 };
 
 #endif /* XSYNCBASEDPOLLER_H */
